@@ -2,6 +2,7 @@ import pandas as pd
 import tweepy
 #from utils.auth import authHandler # adding utils function for auth
 
+
 def user_info(consumer_key_input, consumer_secret_input, access_token_input, access_token_secret_input):
     """Take four input parameters with user credentials and stored in a list object.
     Parameters
@@ -40,19 +41,20 @@ def load_twitter_by_user(user, limit, user_info):
     Parameters
     ----------
     user : str
-        twitter user_name.
+        Twitter user_name.
 
     limit : int
-        how many tweets you wanna return.
+        How many tweets you wanna return.
+
     Returns
     -------
-    dataframe
-        dataframe contains username's twitter info.
+    pd.DataFrame : 
+        Dataframe contains username's twitter info.
+
     Examples
     --------
     load_twitter_by_user('Cristiano', 300)
     """
-
     consumer_key = user_info['consumer_key']
     consumer_secret = user_info['consumer_secret']
     access_token = user_info['access_token']
@@ -63,14 +65,16 @@ def load_twitter_by_user(user, limit, user_info):
     api = tweepy.API(auth)
 
     tweets = tweepy.Cursor(api.user_timeline, screen_name=user, count=200, tweet_mode='extended').items(limit)
+
     # create DataFrame
     columns = ['User', 'Id', "created_at","favorite_count","retweet_count", "text" ]
     data = []
+
     for tweet in tweets:
         data.append([tweet.user.screen_name, tweet.id_str, tweet.created_at, tweet.favorite_count, tweet.retweet_count, tweet.full_text.encode("utf-8").decode("utf-8")])
         df = pd.DataFrame(data, columns=columns)
-    return df
 
+    return df
 
 
 def load_twitter_by_keywords(key, limit, user_info):
@@ -82,10 +86,12 @@ def load_twitter_by_keywords(key, limit, user_info):
 
     limit : int
         how many tweets you wanna return.
+
     Returns
     -------
     dataframe
         dataframe contains username's twitter info.
+
     Examples
     --------
     load_twitter_by_keywords('2022', 100)
@@ -100,10 +106,12 @@ def load_twitter_by_keywords(key, limit, user_info):
     
     api = tweepy.API(auth)
     tweets = tweepy.Cursor(api.search_tweets, q=key, count=100, tweet_mode='extended').items(limit)
+
     # create DataFrame
     columns = ['User', 'Id', "created_at","favorite_count","retweet_count", "text" ]
     data = []
     for tweet in tweets:
         data.append([tweet.user.screen_name, tweet.id_str, tweet.created_at, tweet.favorite_count, tweet.retweet_count, tweet.full_text.encode("utf-8").decode("utf-8")])
         df = pd.DataFrame(data, columns=columns)
+        
     return df
\ No newline at end of file
